aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorBryan Newbold <bnewbold@robocracy.org>2019-09-05 18:44:40 -0700
committerBryan Newbold <bnewbold@robocracy.org>2019-09-05 18:44:40 -0700
commit070069cb6eb71b92a9c4e46f3d4cfabb67f4eb3f (patch)
tree82f82c5586bd97c2ed5c4082f85d571f23a4182b
parent180bb7366587bc4150108e4e0274806ce285d6a6 (diff)
downloadfatcat-070069cb6eb71b92a9c4e46f3d4cfabb67f4eb3f.tar.gz
fatcat-070069cb6eb71b92a9c4e46f3d4cfabb67f4eb3f.zip
rename python client to 'fatcat-openapi-client'
-rw-r--r--python_client/fatcat_client/__init__.py58
-rw-r--r--python_client/fatcat_client/models/__init__.py51
-rw-r--r--python_openapi_client/.gitignore (renamed from python_client/.gitignore)0
-rw-r--r--python_openapi_client/README.md (renamed from python_client/README.md)16
-rwxr-xr-xpython_openapi_client/codegen_python_client.sh (renamed from python_client/codegen_python_client.sh)44
-rw-r--r--python_openapi_client/conftest.py (renamed from python_client/conftest.py)2
-rw-r--r--python_openapi_client/fatcat_openapi_client/__init__.py58
-rw-r--r--python_openapi_client/fatcat_openapi_client/__version__.py (renamed from python_client/fatcat_client/__version__.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/api/__init__.py (renamed from python_client/fatcat_client/api/__init__.py)2
-rw-r--r--python_openapi_client/fatcat_openapi_client/api/default_api.py (renamed from python_client/fatcat_client/api/default_api.py)2
-rw-r--r--python_openapi_client/fatcat_openapi_client/api_client.py (renamed from python_client/fatcat_client/api_client.py)8
-rw-r--r--python_openapi_client/fatcat_openapi_client/configuration.py (renamed from python_client/fatcat_client/configuration.py)2
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/__init__.py51
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/auth_oidc.py (renamed from python_client/fatcat_client/models/auth_oidc.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/auth_oidc_result.py (renamed from python_client/fatcat_client/models/auth_oidc_result.py)2
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/changelog_entry.py (renamed from python_client/fatcat_client/models/changelog_entry.py)2
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/container_auto_batch.py (renamed from python_client/fatcat_client/models/container_auto_batch.py)4
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/container_entity.py (renamed from python_client/fatcat_client/models/container_entity.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/creator_auto_batch.py (renamed from python_client/fatcat_client/models/creator_auto_batch.py)4
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/creator_entity.py (renamed from python_client/fatcat_client/models/creator_entity.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/editgroup.py (renamed from python_client/fatcat_client/models/editgroup.py)6
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/editgroup_annotation.py (renamed from python_client/fatcat_client/models/editgroup_annotation.py)2
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/editgroup_edits.py (renamed from python_client/fatcat_client/models/editgroup_edits.py)2
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/editor.py (renamed from python_client/fatcat_client/models/editor.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/entity_edit.py (renamed from python_client/fatcat_client/models/entity_edit.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/entity_history_entry.py (renamed from python_client/fatcat_client/models/entity_history_entry.py)6
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/error_response.py (renamed from python_client/fatcat_client/models/error_response.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/file_auto_batch.py (renamed from python_client/fatcat_client/models/file_auto_batch.py)4
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/file_entity.py (renamed from python_client/fatcat_client/models/file_entity.py)2
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/file_url.py (renamed from python_client/fatcat_client/models/file_url.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/fileset_auto_batch.py (renamed from python_client/fatcat_client/models/fileset_auto_batch.py)4
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/fileset_entity.py (renamed from python_client/fatcat_client/models/fileset_entity.py)4
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/fileset_file.py (renamed from python_client/fatcat_client/models/fileset_file.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/fileset_url.py (renamed from python_client/fatcat_client/models/fileset_url.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/release_abstract.py (renamed from python_client/fatcat_client/models/release_abstract.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/release_auto_batch.py (renamed from python_client/fatcat_client/models/release_auto_batch.py)4
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/release_contrib.py (renamed from python_client/fatcat_client/models/release_contrib.py)2
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/release_entity.py (renamed from python_client/fatcat_client/models/release_entity.py)16
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/release_ext_ids.py (renamed from python_client/fatcat_client/models/release_ext_ids.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/release_ref.py (renamed from python_client/fatcat_client/models/release_ref.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/success.py (renamed from python_client/fatcat_client/models/success.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/webcapture_auto_batch.py (renamed from python_client/fatcat_client/models/webcapture_auto_batch.py)4
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/webcapture_cdx_line.py (renamed from python_client/fatcat_client/models/webcapture_cdx_line.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/webcapture_entity.py (renamed from python_client/fatcat_client/models/webcapture_entity.py)4
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/webcapture_url.py (renamed from python_client/fatcat_client/models/webcapture_url.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/work_auto_batch.py (renamed from python_client/fatcat_client/models/work_auto_batch.py)4
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/work_entity.py (renamed from python_client/fatcat_client/models/work_entity.py)0
-rw-r--r--python_openapi_client/fatcat_openapi_client/rest.py (renamed from python_client/fatcat_client/rest.py)0
-rw-r--r--python_openapi_client/pytest.ini (renamed from python_client/pytest.ini)2
-rw-r--r--python_openapi_client/setup.py (renamed from python_client/setup.py)6
-rw-r--r--python_openapi_client/tests/codegen/__init__.py (renamed from python_client/tests/codegen/__init__.py)0
-rw-r--r--python_openapi_client/tests/codegen/test_auth_oidc.py (renamed from python_client/tests/codegen/test_auth_oidc.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_auth_oidc_result.py (renamed from python_client/tests/codegen/test_auth_oidc_result.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_changelog_entry.py (renamed from python_client/tests/codegen/test_changelog_entry.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_container_auto_batch.py (renamed from python_client/tests/codegen/test_container_auto_batch.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_container_entity.py (renamed from python_client/tests/codegen/test_container_entity.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_creator_auto_batch.py (renamed from python_client/tests/codegen/test_creator_auto_batch.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_creator_entity.py (renamed from python_client/tests/codegen/test_creator_entity.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_default_api.py (renamed from python_client/tests/codegen/test_default_api.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_editgroup.py (renamed from python_client/tests/codegen/test_editgroup.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_editgroup_annotation.py (renamed from python_client/tests/codegen/test_editgroup_annotation.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_editgroup_edits.py (renamed from python_client/tests/codegen/test_editgroup_edits.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_editor.py (renamed from python_client/tests/codegen/test_editor.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_entity_edit.py (renamed from python_client/tests/codegen/test_entity_edit.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_entity_history_entry.py (renamed from python_client/tests/codegen/test_entity_history_entry.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_error_response.py (renamed from python_client/tests/codegen/test_error_response.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_file_auto_batch.py (renamed from python_client/tests/codegen/test_file_auto_batch.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_file_entity.py (renamed from python_client/tests/codegen/test_file_entity.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_file_url.py (renamed from python_client/tests/codegen/test_file_url.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_fileset_auto_batch.py (renamed from python_client/tests/codegen/test_fileset_auto_batch.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_fileset_entity.py (renamed from python_client/tests/codegen/test_fileset_entity.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_fileset_file.py (renamed from python_client/tests/codegen/test_fileset_file.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_fileset_url.py (renamed from python_client/tests/codegen/test_fileset_url.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_release_abstract.py (renamed from python_client/tests/codegen/test_release_abstract.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_release_auto_batch.py (renamed from python_client/tests/codegen/test_release_auto_batch.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_release_contrib.py (renamed from python_client/tests/codegen/test_release_contrib.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_release_entity.py (renamed from python_client/tests/codegen/test_release_entity.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_release_ext_ids.py (renamed from python_client/tests/codegen/test_release_ext_ids.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_release_ref.py (renamed from python_client/tests/codegen/test_release_ref.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_success.py (renamed from python_client/tests/codegen/test_success.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_webcapture_auto_batch.py (renamed from python_client/tests/codegen/test_webcapture_auto_batch.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_webcapture_cdx_line.py (renamed from python_client/tests/codegen/test_webcapture_cdx_line.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_webcapture_entity.py (renamed from python_client/tests/codegen/test_webcapture_entity.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_webcapture_url.py (renamed from python_client/tests/codegen/test_webcapture_url.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_work_auto_batch.py (renamed from python_client/tests/codegen/test_work_auto_batch.py)8
-rw-r--r--python_openapi_client/tests/codegen/test_work_entity.py (renamed from python_client/tests/codegen/test_work_entity.py)8
86 files changed, 329 insertions, 329 deletions
diff --git a/python_client/fatcat_client/__init__.py b/python_client/fatcat_client/__init__.py
deleted file mode 100644
index ef0b6e3f..00000000
--- a/python_client/fatcat_client/__init__.py
+++ /dev/null
@@ -1,58 +0,0 @@
-# coding: utf-8
-
-# flake8: noqa
-
-"""
- fatcat
-
- A scalable, versioned, API-oriented catalog of bibliographic entities and file metadata # noqa: E501
-
- OpenAPI spec version: 0.3.0
-
- Generated by: https://github.com/swagger-api/swagger-codegen.git
-"""
-
-
-from __future__ import absolute_import
-
-# import apis into sdk package
-from fatcat_client.api.default_api import DefaultApi
-
-# import ApiClient
-from fatcat_client.api_client import ApiClient
-from fatcat_client.configuration import Configuration
-# import models into sdk package
-from fatcat_client.models.auth_oidc import AuthOidc
-from fatcat_client.models.auth_oidc_result import AuthOidcResult
-from fatcat_client.models.changelog_entry import ChangelogEntry
-from fatcat_client.models.container_auto_batch import ContainerAutoBatch
-from fatcat_client.models.container_entity import ContainerEntity
-from fatcat_client.models.creator_auto_batch import CreatorAutoBatch
-from fatcat_client.models.creator_entity import CreatorEntity
-from fatcat_client.models.editgroup import Editgroup
-from fatcat_client.models.editgroup_annotation import EditgroupAnnotation
-from fatcat_client.models.editgroup_edits import EditgroupEdits
-from fatcat_client.models.editor import Editor
-from fatcat_client.models.entity_edit import EntityEdit
-from fatcat_client.models.entity_history_entry import EntityHistoryEntry
-from fatcat_client.models.error_response import ErrorResponse
-from fatcat_client.models.file_auto_batch import FileAutoBatch
-from fatcat_client.models.file_entity import FileEntity
-from fatcat_client.models.file_url import FileUrl
-from fatcat_client.models.fileset_auto_batch import FilesetAutoBatch
-from fatcat_client.models.fileset_entity import FilesetEntity
-from fatcat_client.models.fileset_file import FilesetFile
-from fatcat_client.models.fileset_url import FilesetUrl
-from fatcat_client.models.release_abstract import ReleaseAbstract
-from fatcat_client.models.release_auto_batch import ReleaseAutoBatch
-from fatcat_client.models.release_contrib import ReleaseContrib
-from fatcat_client.models.release_entity import ReleaseEntity
-from fatcat_client.models.release_ext_ids import ReleaseExtIds
-from fatcat_client.models.release_ref import ReleaseRef
-from fatcat_client.models.success import Success
-from fatcat_client.models.webcapture_auto_batch import WebcaptureAutoBatch
-from fatcat_client.models.webcapture_cdx_line import WebcaptureCdxLine
-from fatcat_client.models.webcapture_entity import WebcaptureEntity
-from fatcat_client.models.webcapture_url import WebcaptureUrl
-from fatcat_client.models.work_auto_batch import WorkAutoBatch
-from fatcat_client.models.work_entity import WorkEntity
diff --git a/python_client/fatcat_client/models/__init__.py b/python_client/fatcat_client/models/__init__.py
deleted file mode 100644
index 574c7aeb..00000000
--- a/python_client/fatcat_client/models/__init__.py
+++ /dev/null
@@ -1,51 +0,0 @@
-# coding: utf-8
-
-# flake8: noqa
-"""
- fatcat
-
- A scalable, versioned, API-oriented catalog of bibliographic entities and file metadata # noqa: E501
-
- OpenAPI spec version: 0.3.0
-
- Generated by: https://github.com/swagger-api/swagger-codegen.git
-"""
-
-
-from __future__ import absolute_import
-
-# import models into model package
-from fatcat_client.models.auth_oidc import AuthOidc
-from fatcat_client.models.auth_oidc_result import AuthOidcResult
-from fatcat_client.models.changelog_entry import ChangelogEntry
-from fatcat_client.models.container_auto_batch import ContainerAutoBatch
-from fatcat_client.models.container_entity import ContainerEntity
-from fatcat_client.models.creator_auto_batch import CreatorAutoBatch
-from fatcat_client.models.creator_entity import CreatorEntity
-from fatcat_client.models.editgroup import Editgroup
-from fatcat_client.models.editgroup_annotation import EditgroupAnnotation
-from fatcat_client.models.editgroup_edits import EditgroupEdits
-from fatcat_client.models.editor import Editor
-from fatcat_client.models.entity_edit import EntityEdit
-from fatcat_client.models.entity_history_entry import EntityHistoryEntry
-from fatcat_client.models.error_response import ErrorResponse
-from fatcat_client.models.file_auto_batch import FileAutoBatch
-from fatcat_client.models.file_entity import FileEntity
-from fatcat_client.models.file_url import FileUrl
-from fatcat_client.models.fileset_auto_batch import FilesetAutoBatch
-from fatcat_client.models.fileset_entity import FilesetEntity
-from fatcat_client.models.fileset_file import FilesetFile
-from fatcat_client.models.fileset_url import FilesetUrl
-from fatcat_client.models.release_abstract import ReleaseAbstract
-from fatcat_client.models.release_auto_batch import ReleaseAutoBatch
-from fatcat_client.models.release_contrib import ReleaseContrib
-from fatcat_client.models.release_entity import ReleaseEntity
-from fatcat_client.models.release_ext_ids import ReleaseExtIds
-from fatcat_client.models.release_ref import ReleaseRef
-from fatcat_client.models.success import Success
-from fatcat_client.models.webcapture_auto_batch import WebcaptureAutoBatch
-from fatcat_client.models.webcapture_cdx_line import WebcaptureCdxLine
-from fatcat_client.models.webcapture_entity import WebcaptureEntity
-from fatcat_client.models.webcapture_url import WebcaptureUrl
-from fatcat_client.models.work_auto_batch import WorkAutoBatch
-from fatcat_client.models.work_entity import WorkEntity
diff --git a/python_client/.gitignore b/python_openapi_client/.gitignore
index a0bc258b..a0bc258b 100644
--- a/python_client/.gitignore
+++ b/python_openapi_client/.gitignore
diff --git a/python_client/README.md b/python_openapi_client/README.md
index c69ae551..0e75f1d1 100644
--- a/python_client/README.md
+++ b/python_openapi_client/README.md
@@ -1,4 +1,4 @@
-# fatcat-client
+# fatcat-openapi-client
A scalable, versioned, API-oriented catalog of bibliographic entities and file metadata
This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:
@@ -23,7 +23,7 @@ pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
Then import the package:
```python
-import fatcat_client
+import fatcat_openapi_client
```
### Setuptools
@@ -37,7 +37,7 @@ python setup.py install --user
Then import the package:
```python
-import fatcat_client
+import fatcat_openapi_client
```
## Getting Started
@@ -47,16 +47,16 @@ Please follow the [installation procedure](#installation--usage) and then run th
```python
from __future__ import print_function
import time
-import fatcat_client
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.rest import ApiException
from pprint import pprint
# Configure API key authorization: Bearer
-fatcat_client.configuration.api_key['Authorization'] = 'YOUR_API_KEY'
+fatcat_openapi_client.configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
-# fatcat_client.configuration.api_key_prefix['Authorization'] = 'Bearer'
+# fatcat_openapi_client.configuration.api_key_prefix['Authorization'] = 'Bearer'
# create an instance of the API class
-api_instance = fatcat_client.DefaultApi()
+api_instance = fatcat_openapi_client.DefaultApi()
editgroup_id = 'editgroup_id_example' # str | base32-encoded unique identifier
try:
diff --git a/python_client/conftest.py b/python_openapi_client/conftest.py
index c2a31562..144e323c 100644
--- a/python_client/conftest.py
+++ b/python_openapi_client/conftest.py
@@ -1,6 +1,6 @@
"""
This file exists soley to prevent pytest from trying to import/test the
-fatcat_client ./setup.py file.
+fatcat_openapi_client ./setup.py file.
"""
import sys
diff --git a/python_openapi_client/fatcat_openapi_client/__init__.py b/python_openapi_client/fatcat_openapi_client/__init__.py
new file mode 100644
index 00000000..b9fb0303
--- /dev/null
+++ b/python_openapi_client/fatcat_openapi_client/__init__.py
@@ -0,0 +1,58 @@
+# coding: utf-8
+
+# flake8: noqa
+
+"""
+ fatcat
+
+ A scalable, versioned, API-oriented catalog of bibliographic entities and file metadata # noqa: E501
+
+ OpenAPI spec version: 0.3.0
+
+ Generated by: https://github.com/swagger-api/swagger-codegen.git
+"""
+
+
+from __future__ import absolute_import
+
+# import apis into sdk package
+from fatcat_openapi_client.api.default_api import DefaultApi
+
+# import ApiClient
+from fatcat_openapi_client.api_client import ApiClient
+from fatcat_openapi_client.configuration import Configuration
+# import models into sdk package
+from fatcat_openapi_client.models.auth_oidc import AuthOidc
+from fatcat_openapi_client.models.auth_oidc_result import AuthOidcResult
+from fatcat_openapi_client.models.changelog_entry import ChangelogEntry
+from fatcat_openapi_client.models.container_auto_batch import ContainerAutoBatch
+from fatcat_openapi_client.models.container_entity import ContainerEntity
+from fatcat_openapi_client.models.creator_auto_batch import CreatorAutoBatch
+from fatcat_openapi_client.models.creator_entity import CreatorEntity
+from fatcat_openapi_client.models.editgroup import Editgroup
+from fatcat_openapi_client.models.editgroup_annotation import EditgroupAnnotation
+from fatcat_openapi_client.models.editgroup_edits import EditgroupEdits
+from fatcat_openapi_client.models.editor import Editor
+from fatcat_openapi_client.models.entity_edit import EntityEdit
+from fatcat_openapi_client.models.entity_history_entry import EntityHistoryEntry
+from fatcat_openapi_client.models.error_response import ErrorResponse
+from fatcat_openapi_client.models.file_auto_batch import FileAutoBatch
+from fatcat_openapi_client.models.file_entity import FileEntity
+from fatcat_openapi_client.models.file_url import FileUrl
+from fatcat_openapi_client.models.fileset_auto_batch import FilesetAutoBatch
+from fatcat_openapi_client.models.fileset_entity import FilesetEntity
+from fatcat_openapi_client.models.fileset_file import FilesetFile
+from fatcat_openapi_client.models.fileset_url import FilesetUrl
+from fatcat_openapi_client.models.release_abstract import ReleaseAbstract
+from fatcat_openapi_client.models.release_auto_batch import ReleaseAutoBatch
+from fatcat_openapi_client.models.release_contrib import ReleaseContrib
+from fatcat_openapi_client.models.release_entity import ReleaseEntity
+from fatcat_openapi_client.models.release_ext_ids import ReleaseExtIds
+from fatcat_openapi_client.models.release_ref import ReleaseRef
+from fatcat_openapi_client.models.success import Success
+from fatcat_openapi_client.models.webcapture_auto_batch import WebcaptureAutoBatch
+from fatcat_openapi_client.models.webcapture_cdx_line import WebcaptureCdxLine
+from fatcat_openapi_client.models.webcapture_entity import WebcaptureEntity
+from fatcat_openapi_client.models.webcapture_url import WebcaptureUrl
+from fatcat_openapi_client.models.work_auto_batch import WorkAutoBatch
+from fatcat_openapi_client.models.work_entity import WorkEntity
diff --git a/python_client/fatcat_client/__version__.py b/python_openapi_client/fatcat_openapi_client/__version__.py
index a85c1f92..a85c1f92 100644
--- a/python_client/fatcat_client/__version__.py
+++ b/python_openapi_client/fatcat_openapi_client/__version__.py
diff --git a/python_client/fatcat_client/api/__init__.py b/python_openapi_client/fatcat_openapi_client/api/__init__.py
index 79b04b0c..cdd759f9 100644
--- a/python_client/fatcat_client/api/__init__.py
+++ b/python_openapi_client/fatcat_openapi_client/api/__init__.py
@@ -3,4 +3,4 @@ from __future__ import absolute_import
# flake8: noqa
# import apis into api package
-from fatcat_client.api.default_api import DefaultApi
+from fatcat_openapi_client.api.default_api import DefaultApi
diff --git a/python_client/fatcat_client/api/default_api.py b/python_openapi_client/fatcat_openapi_client/api/default_api.py
index 0ea79748..a15d9f06 100644
--- a/python_client/fatcat_client/api/default_api.py
+++ b/python_openapi_client/fatcat_openapi_client/api/default_api.py
@@ -18,7 +18,7 @@ import re # noqa: F401
# python 2 and python 3 compatibility library
import six
-from fatcat_client.api_client import ApiClient
+from fatcat_openapi_client.api_client import ApiClient
class DefaultApi(object):
diff --git a/python_client/fatcat_client/api_client.py b/python_openapi_client/fatcat_openapi_client/api_client.py
index 98256e65..af0ddfb7 100644
--- a/python_client/fatcat_client/api_client.py
+++ b/python_openapi_client/fatcat_openapi_client/api_client.py
@@ -23,9 +23,9 @@ import tempfile
import six
from six.moves.urllib.parse import quote
-from fatcat_client.configuration import Configuration
-import fatcat_client.models
-from fatcat_client import rest
+from fatcat_openapi_client.configuration import Configuration
+import fatcat_openapi_client.models
+from fatcat_openapi_client import rest
class ApiClient(object):
@@ -261,7 +261,7 @@ class ApiClient(object):
if klass in self.NATIVE_TYPES_MAPPING:
klass = self.NATIVE_TYPES_MAPPING[klass]
else:
- klass = getattr(fatcat_client.models, klass)
+ klass = getattr(fatcat_openapi_client.models, klass)
if klass in self.PRIMITIVE_TYPES:
return self.__deserialize_primitive(data, klass)
diff --git a/python_client/fatcat_client/configuration.py b/python_openapi_client/fatcat_openapi_client/configuration.py
index 7a79fa79..8294f584 100644
--- a/python_client/fatcat_client/configuration.py
+++ b/python_openapi_client/fatcat_openapi_client/configuration.py
@@ -63,7 +63,7 @@ class Configuration(object):
# Logging Settings
self.logger = {}
- self.logger["package_logger"] = logging.getLogger("fatcat_client")
+ self.logger["package_logger"] = logging.getLogger("fatcat_openapi_client")
self.logger["urllib3_logger"] = logging.getLogger("urllib3")
# Log format
self.logger_format = '%(asctime)s %(levelname)s %(message)s'
diff --git a/python_openapi_client/fatcat_openapi_client/models/__init__.py b/python_openapi_client/fatcat_openapi_client/models/__init__.py
new file mode 100644
index 00000000..751e4a68
--- /dev/null
+++ b/python_openapi_client/fatcat_openapi_client/models/__init__.py
@@ -0,0 +1,51 @@
+# coding: utf-8
+
+# flake8: noqa
+"""
+ fatcat
+
+ A scalable, versioned, API-oriented catalog of bibliographic entities and file metadata # noqa: E501
+
+ OpenAPI spec version: 0.3.0
+
+ Generated by: https://github.com/swagger-api/swagger-codegen.git
+"""
+
+
+from __future__ import absolute_import
+
+# import models into model package
+from fatcat_openapi_client.models.auth_oidc import AuthOidc
+from fatcat_openapi_client.models.auth_oidc_result import AuthOidcResult
+from fatcat_openapi_client.models.changelog_entry import ChangelogEntry
+from fatcat_openapi_client.models.container_auto_batch import ContainerAutoBatch
+from fatcat_openapi_client.models.container_entity import ContainerEntity
+from fatcat_openapi_client.models.creator_auto_batch import CreatorAutoBatch
+from fatcat_openapi_client.models.creator_entity import CreatorEntity
+from fatcat_openapi_client.models.editgroup import Editgroup
+from fatcat_openapi_client.models.editgroup_annotation import EditgroupAnnotation
+from fatcat_openapi_client.models.editgroup_edits import EditgroupEdits
+from fatcat_openapi_client.models.editor import Editor
+from fatcat_openapi_client.models.entity_edit import EntityEdit
+from fatcat_openapi_client.models.entity_history_entry import EntityHistoryEntry
+from fatcat_openapi_client.models.error_response import ErrorResponse
+from fatcat_openapi_client.models.file_auto_batch import FileAutoBatch
+from fatcat_openapi_client.models.file_entity import FileEntity
+from fatcat_openapi_client.models.file_url import FileUrl
+from fatcat_openapi_client.models.fileset_auto_batch import FilesetAutoBatch
+from fatcat_openapi_client.models.fileset_entity import FilesetEntity
+from fatcat_openapi_client.models.fileset_file import FilesetFile
+from fatcat_openapi_client.models.fileset_url import FilesetUrl
+from fatcat_openapi_client.models.release_abstract import ReleaseAbstract
+from fatcat_openapi_client.models.release_auto_batch import ReleaseAutoBatch
+from fatcat_openapi_client.models.release_contrib import ReleaseContrib
+from fatcat_openapi_client.models.release_entity import ReleaseEntity
+from fatcat_openapi_client.models.release_ext_ids import ReleaseExtIds
+from fatcat_openapi_client.models.release_ref import ReleaseRef
+from fatcat_openapi_client.models.success import Success
+from fatcat_openapi_client.models.webcapture_auto_batch import WebcaptureAutoBatch
+from fatcat_openapi_client.models.webcapture_cdx_line import WebcaptureCdxLine
+from fatcat_openapi_client.models.webcapture_entity import WebcaptureEntity
+from fatcat_openapi_client.models.webcapture_url import WebcaptureUrl
+from fatcat_openapi_client.models.work_auto_batch import WorkAutoBatch
+from fatcat_openapi_client.models.work_entity import WorkEntity
diff --git a/python_client/fatcat_client/models/auth_oidc.py b/python_openapi_client/fatcat_openapi_client/models/auth_oidc.py
index 5d11adab..5d11adab 100644
--- a/python_client/fatcat_client/models/auth_oidc.py
+++ b/python_openapi_client/fatcat_openapi_client/models/auth_oidc.py
diff --git a/python_client/fatcat_client/models/auth_oidc_result.py b/python_openapi_client/fatcat_openapi_client/models/auth_oidc_result.py
index 2ac7d736..ef2d7f32 100644
--- a/python_client/fatcat_client/models/auth_oidc_result.py
+++ b/python_openapi_client/fatcat_openapi_client/models/auth_oidc_result.py
@@ -16,7 +16,7 @@ import re # noqa: F401
import six
-from fatcat_client.models.editor import Editor # noqa: F401,E501
+from fatcat_openapi_client.models.editor import Editor # noqa: F401,E501
class AuthOidcResult(object):
diff --git a/python_client/fatcat_client/models/changelog_entry.py b/python_openapi_client/fatcat_openapi_client/models/changelog_entry.py
index ae4e7afb..893a3d2b 100644
--- a/python_client/fatcat_client/models/changelog_entry.py
+++ b/python_openapi_client/fatcat_openapi_client/models/changelog_entry.py
@@ -16,7 +16,7 @@ import re # noqa: F401
import six
-from fatcat_client.models.editgroup import Editgroup # noqa: F401,E501
+from fatcat_openapi_client.models.editgroup import Editgroup # noqa: F401,E501
class ChangelogEntry(object):
diff --git a/python_client/fatcat_client/models/container_auto_batch.py b/python_openapi_client/fatcat_openapi_client/models/container_auto_batch.py
index 6592b89f..2a431196 100644
--- a/python_client/fatcat_client/models/container_auto_batch.py
+++ b/python_openapi_client/fatcat_openapi_client/models/container_auto_batch.py
@@ -16,8 +16,8 @@ import re # noqa: F401
import six
-from fatcat_client.models.container_entity import ContainerEntity # noqa: F401,E501
-from fatcat_client.models.editgroup import Editgroup # noqa: F401,E501
+from fatcat_openapi_client.models.container_entity import ContainerEntity # noqa: F401,E501
+from fatcat_openapi_client.models.editgroup import Editgroup # noqa: F401,E501
class ContainerAutoBatch(object):
diff --git a/python_client/fatcat_client/models/container_entity.py b/python_openapi_client/fatcat_openapi_client/models/container_entity.py
index 5fb1a51b..5fb1a51b 100644
--- a/python_client/fatcat_client/models/container_entity.py
+++ b/python_openapi_client/fatcat_openapi_client/models/container_entity.py
diff --git a/python_client/fatcat_client/models/creator_auto_batch.py b/python_openapi_client/fatcat_openapi_client/models/creator_auto_batch.py
index 45cf4c25..6080c7dc 100644
--- a/python_client/fatcat_client/models/creator_auto_batch.py
+++ b/python_openapi_client/fatcat_openapi_client/models/creator_auto_batch.py
@@ -16,8 +16,8 @@ import re # noqa: F401
import six
-from fatcat_client.models.creator_entity import CreatorEntity # noqa: F401,E501
-from fatcat_client.models.editgroup import Editgroup # noqa: F401,E501
+from fatcat_openapi_client.models.creator_entity import CreatorEntity # noqa: F401,E501
+from fatcat_openapi_client.models.editgroup import Editgroup # noqa: F401,E501
class CreatorAutoBatch(object):
diff --git a/python_client/fatcat_client/models/creator_entity.py b/python_openapi_client/fatcat_openapi_client/models/creator_entity.py
index d015701b..d015701b 100644
--- a/python_client/fatcat_client/models/creator_entity.py
+++ b/python_openapi_client/fatcat_openapi_client/models/creator_entity.py
diff --git a/python_client/fatcat_client/models/editgroup.py b/python_openapi_client/fatcat_openapi_client/models/editgroup.py
index 03d644de..4874f528 100644
--- a/python_client/fatcat_client/models/editgroup.py
+++ b/python_openapi_client/fatcat_openapi_client/models/editgroup.py
@@ -16,9 +16,9 @@ import re # noqa: F401
import six
-from fatcat_client.models.editgroup_annotation import EditgroupAnnotation # noqa: F401,E501
-from fatcat_client.models.editgroup_edits import EditgroupEdits # noqa: F401,E501
-from fatcat_client.models.editor import Editor # noqa: F401,E501
+from fatcat_openapi_client.models.editgroup_annotation import EditgroupAnnotation # noqa: F401,E501
+from fatcat_openapi_client.models.editgroup_edits import EditgroupEdits # noqa: F401,E501
+from fatcat_openapi_client.models.editor import Editor # noqa: F401,E501
class Editgroup(object):
diff --git a/python_client/fatcat_client/models/editgroup_annotation.py b/python_openapi_client/fatcat_openapi_client/models/editgroup_annotation.py
index f96fb6dd..d2dde642 100644
--- a/python_client/fatcat_client/models/editgroup_annotation.py
+++ b/python_openapi_client/fatcat_openapi_client/models/editgroup_annotation.py
@@ -16,7 +16,7 @@ import re # noqa: F401
import six
-from fatcat_client.models.editor import Editor # noqa: F401,E501
+from fatcat_openapi_client.models.editor import Editor # noqa: F401,E501
class EditgroupAnnotation(object):
diff --git a/python_client/fatcat_client/models/editgroup_edits.py b/python_openapi_client/fatcat_openapi_client/models/editgroup_edits.py
index ca95c60f..07e6b9fc 100644
--- a/python_client/fatcat_client/models/editgroup_edits.py
+++ b/python_openapi_client/fatcat_openapi_client/models/editgroup_edits.py
@@ -16,7 +16,7 @@ import re # noqa: F401
import six
-from fatcat_client.models.entity_edit import EntityEdit # noqa: F401,E501
+from fatcat_openapi_client.models.entity_edit import EntityEdit # noqa: F401,E501
class EditgroupEdits(object):
diff --git a/python_client/fatcat_client/models/editor.py b/python_openapi_client/fatcat_openapi_client/models/editor.py
index 37657266..37657266 100644
--- a/python_client/fatcat_client/models/editor.py
+++ b/python_openapi_client/fatcat_openapi_client/models/editor.py
diff --git a/python_client/fatcat_client/models/entity_edit.py b/python_openapi_client/fatcat_openapi_client/models/entity_edit.py
index f89817c5..f89817c5 100644
--- a/python_client/fatcat_client/models/entity_edit.py
+++ b/python_openapi_client/fatcat_openapi_client/models/entity_edit.py
diff --git a/python_client/fatcat_client/models/entity_history_entry.py b/python_openapi_client/fatcat_openapi_client/models/entity_history_entry.py
index 8623cc08..5b457202 100644
--- a/python_client/fatcat_client/models/entity_history_entry.py
+++ b/python_openapi_client/fatcat_openapi_client/models/entity_history_entry.py
@@ -16,9 +16,9 @@ import re # noqa: F401
import six
-from fatcat_client.models.changelog_entry import ChangelogEntry # noqa: F401,E501
-from fatcat_client.models.editgroup import Editgroup # noqa: F401,E501
-from fatcat_client.models.entity_edit import EntityEdit # noqa: F401,E501
+from fatcat_openapi_client.models.changelog_entry import ChangelogEntry # noqa: F401,E501
+from fatcat_openapi_client.models.editgroup import Editgroup # noqa: F401,E501
+from fatcat_openapi_client.models.entity_edit import EntityEdit # noqa: F401,E501
class EntityHistoryEntry(object):
diff --git a/python_client/fatcat_client/models/error_response.py b/python_openapi_client/fatcat_openapi_client/models/error_response.py
index 43eafb9b..43eafb9b 100644
--- a/python_client/fatcat_client/models/error_response.py
+++ b/python_openapi_client/fatcat_openapi_client/models/error_response.py
diff --git a/python_client/fatcat_client/models/file_auto_batch.py b/python_openapi_client/fatcat_openapi_client/models/file_auto_batch.py
index 22cdd030..7f8853d2 100644
--- a/python_client/fatcat_client/models/file_auto_batch.py
+++ b/python_openapi_client/fatcat_openapi_client/models/file_auto_batch.py
@@ -16,8 +16,8 @@ import re # noqa: F401
import six
-from fatcat_client.models.editgroup import Editgroup # noqa: F401,E501
-from fatcat_client.models.file_entity import FileEntity # noqa: F401,E501
+from fatcat_openapi_client.models.editgroup import Editgroup # noqa: F401,E501
+from fatcat_openapi_client.models.file_entity import FileEntity # noqa: F401,E501
class FileAutoBatch(object):
diff --git a/python_client/fatcat_client/models/file_entity.py b/python_openapi_client/fatcat_openapi_client/models/file_entity.py
index e80659fe..9f9a558a 100644
--- a/python_client/fatcat_client/models/file_entity.py
+++ b/python_openapi_client/fatcat_openapi_client/models/file_entity.py
@@ -16,7 +16,7 @@ import re # noqa: F401
import six
-from fatcat_client.models.file_url import FileUrl # noqa: F401,E501
+from fatcat_openapi_client.models.file_url import FileUrl # noqa: F401,E501
class FileEntity(object):
diff --git a/python_client/fatcat_client/models/file_url.py b/python_openapi_client/fatcat_openapi_client/models/file_url.py
index cce0d332..cce0d332 100644
--- a/python_client/fatcat_client/models/file_url.py
+++ b/python_openapi_client/fatcat_openapi_client/models/file_url.py
diff --git a/python_client/fatcat_client/models/fileset_auto_batch.py b/python_openapi_client/fatcat_openapi_client/models/fileset_auto_batch.py
index a3075d7a..b252449d 100644
--- a/python_client/fatcat_client/models/fileset_auto_batch.py
+++ b/python_openapi_client/fatcat_openapi_client/models/fileset_auto_batch.py
@@ -16,8 +16,8 @@ import re # noqa: F401
import six
-from fatcat_client.models.editgroup import Editgroup # noqa: F401,E501
-from fatcat_client.models.fileset_entity import FilesetEntity # noqa: F401,E501
+from fatcat_openapi_client.models.editgroup import Editgroup # noqa: F401,E501
+from fatcat_openapi_client.models.fileset_entity import FilesetEntity # noqa: F401,E501
class FilesetAutoBatch(object):
diff --git a/python_client/fatcat_client/models/fileset_entity.py b/python_openapi_client/fatcat_openapi_client/models/fileset_entity.py
index 114c0594..c0d02fd3 100644
--- a/python_client/fatcat_client/models/fileset_entity.py
+++ b/python_openapi_client/fatcat_openapi_client/models/fileset_entity.py
@@ -16,8 +16,8 @@ import re # noqa: F401
import six
-from fatcat_client.models.fileset_file import FilesetFile # noqa: F401,E501
-from fatcat_client.models.fileset_url import FilesetUrl # noqa: F401,E501
+from fatcat_openapi_client.models.fileset_file import FilesetFile # noqa: F401,E501
+from fatcat_openapi_client.models.fileset_url import FilesetUrl # noqa: F401,E501
class FilesetEntity(object):
diff --git a/python_client/fatcat_client/models/fileset_file.py b/python_openapi_client/fatcat_openapi_client/models/fileset_file.py
index 521abc98..521abc98 100644
--- a/python_client/fatcat_client/models/fileset_file.py
+++ b/python_openapi_client/fatcat_openapi_client/models/fileset_file.py
diff --git a/python_client/fatcat_client/models/fileset_url.py b/python_openapi_client/fatcat_openapi_client/models/fileset_url.py
index d0e3a1e7..d0e3a1e7 100644
--- a/python_client/fatcat_client/models/fileset_url.py
+++ b/python_openapi_client/fatcat_openapi_client/models/fileset_url.py
diff --git a/python_client/fatcat_client/models/release_abstract.py b/python_openapi_client/fatcat_openapi_client/models/release_abstract.py
index 173aaa4c..173aaa4c 100644
--- a/python_client/fatcat_client/models/release_abstract.py
+++ b/python_openapi_client/fatcat_openapi_client/models/release_abstract.py
diff --git a/python_client/fatcat_client/models/release_auto_batch.py b/python_openapi_client/fatcat_openapi_client/models/release_auto_batch.py
index f87fc175..30466a78 100644
--- a/python_client/fatcat_client/models/release_auto_batch.py
+++ b/python_openapi_client/fatcat_openapi_client/models/release_auto_batch.py
@@ -16,8 +16,8 @@ import re # noqa: F401
import six
-from fatcat_client.models.editgroup import Editgroup # noqa: F401,E501
-from fatcat_client.models.release_entity import ReleaseEntity # noqa: F401,E501
+from fatcat_openapi_client.models.editgroup import Editgroup # noqa: F401,E501
+from fatcat_openapi_client.models.release_entity import ReleaseEntity # noqa: F401,E501
class ReleaseAutoBatch(object):
diff --git a/python_client/fatcat_client/models/release_contrib.py b/python_openapi_client/fatcat_openapi_client/models/release_contrib.py
index 6b6689c4..8956618a 100644
--- a/python_client/fatcat_client/models/release_contrib.py
+++ b/python_openapi_client/fatcat_openapi_client/models/release_contrib.py
@@ -16,7 +16,7 @@ import re # noqa: F401
import six
-from fatcat_client.models.creator_entity import CreatorEntity # noqa: F401,E501
+from fatcat_openapi_client.models.creator_entity import CreatorEntity # noqa: F401,E501
class ReleaseContrib(object):
diff --git a/python_client/fatcat_client/models/release_entity.py b/python_openapi_client/fatcat_openapi_client/models/release_entity.py
index 81d1779d..119f5b1d 100644
--- a/python_client/fatcat_client/models/release_entity.py
+++ b/python_openapi_client/fatcat_openapi_client/models/release_entity.py
@@ -16,14 +16,14 @@ import re # noqa: F401
import six
-from fatcat_client.models.container_entity import ContainerEntity # noqa: F401,E501
-from fatcat_client.models.file_entity import FileEntity # noqa: F401,E501
-from fatcat_client.models.fileset_entity import FilesetEntity # noqa: F401,E501
-from fatcat_client.models.release_abstract import ReleaseAbstract # noqa: F401,E501
-from fatcat_client.models.release_contrib import ReleaseContrib # noqa: F401,E501
-from fatcat_client.models.release_ext_ids import ReleaseExtIds # noqa: F401,E501
-from fatcat_client.models.release_ref import ReleaseRef # noqa: F401,E501
-from fatcat_client.models.webcapture_entity import WebcaptureEntity # noqa: F401,E501
+from fatcat_openapi_client.models.container_entity import ContainerEntity # noqa: F401,E501
+from fatcat_openapi_client.models.file_entity import FileEntity # noqa: F401,E501
+from fatcat_openapi_client.models.fileset_entity import FilesetEntity # noqa: F401,E501
+from fatcat_openapi_client.models.release_abstract import ReleaseAbstract # noqa: F401,E501
+from fatcat_openapi_client.models.release_contrib import ReleaseContrib # noqa: F401,E501
+from fatcat_openapi_client.models.release_ext_ids import ReleaseExtIds # noqa: F401,E501
+from fatcat_openapi_client.models.release_ref import ReleaseRef # noqa: F401,E501
+from fatcat_openapi_client.models.webcapture_entity import WebcaptureEntity # noqa: F401,E501
class ReleaseEntity(object):
diff --git a/python_client/fatcat_client/models/release_ext_ids.py b/python_openapi_client/fatcat_openapi_client/models/release_ext_ids.py
index 7c6eb2dd..7c6eb2dd 100644
--- a/python_client/fatcat_client/models/release_ext_ids.py
+++ b/python_openapi_client/fatcat_openapi_client/models/release_ext_ids.py
diff --git a/python_client/fatcat_client/models/release_ref.py b/python_openapi_client/fatcat_openapi_client/models/release_ref.py
index ed44158b..ed44158b 100644
--- a/python_client/fatcat_client/models/release_ref.py
+++ b/python_openapi_client/fatcat_openapi_client/models/release_ref.py
diff --git a/python_client/fatcat_client/models/success.py b/python_openapi_client/fatcat_openapi_client/models/success.py
index 337efebb..337efebb 100644
--- a/python_client/fatcat_client/models/success.py
+++ b/python_openapi_client/fatcat_openapi_client/models/success.py
diff --git a/python_client/fatcat_client/models/webcapture_auto_batch.py b/python_openapi_client/fatcat_openapi_client/models/webcapture_auto_batch.py
index 003e5acb..cc968f8b 100644
--- a/python_client/fatcat_client/models/webcapture_auto_batch.py
+++ b/python_openapi_client/fatcat_openapi_client/models/webcapture_auto_batch.py
@@ -16,8 +16,8 @@ import re # noqa: F401
import six
-from fatcat_client.models.editgroup import Editgroup # noqa: F401,E501
-from fatcat_client.models.webcapture_entity import WebcaptureEntity # noqa: F401,E501
+from fatcat_openapi_client.models.editgroup import Editgroup # noqa: F401,E501
+from fatcat_openapi_client.models.webcapture_entity import WebcaptureEntity # noqa: F401,E501
class WebcaptureAutoBatch(object):
diff --git a/python_client/fatcat_client/models/webcapture_cdx_line.py b/python_openapi_client/fatcat_openapi_client/models/webcapture_cdx_line.py
index 623607ba..623607ba 100644
--- a/python_client/fatcat_client/models/webcapture_cdx_line.py
+++ b/python_openapi_client/fatcat_openapi_client/models/webcapture_cdx_line.py
diff --git a/python_client/fatcat_client/models/webcapture_entity.py b/python_openapi_client/fatcat_openapi_client/models/webcapture_entity.py
index 33098001..af4748c5 100644
--- a/python_client/fatcat_client/models/webcapture_entity.py
+++ b/python_openapi_client/fatcat_openapi_client/models/webcapture_entity.py
@@ -16,8 +16,8 @@ import re # noqa: F401
import six
-from fatcat_client.models.webcapture_cdx_line import WebcaptureCdxLine # noqa: F401,E501
-from fatcat_client.models.webcapture_url import WebcaptureUrl # noqa: F401,E501
+from fatcat_openapi_client.models.webcapture_cdx_line import WebcaptureCdxLine # noqa: F401,E501
+from fatcat_openapi_client.models.webcapture_url import WebcaptureUrl # noqa: F401,E501
class WebcaptureEntity(object):
diff --git a/python_client/fatcat_client/models/webcapture_url.py b/python_openapi_client/fatcat_openapi_client/models/webcapture_url.py
index 9d6f1e21..9d6f1e21 100644
--- a/python_client/fatcat_client/models/webcapture_url.py
+++ b/python_openapi_client/fatcat_openapi_client/models/webcapture_url.py
diff --git a/python_client/fatcat_client/models/work_auto_batch.py b/python_openapi_client/fatcat_openapi_client/models/work_auto_batch.py
index 39854d47..76a8ae1e 100644
--- a/python_client/fatcat_client/models/work_auto_batch.py
+++ b/python_openapi_client/fatcat_openapi_client/models/work_auto_batch.py
@@ -16,8 +16,8 @@ import re # noqa: F401
import six
-from fatcat_client.models.editgroup import Editgroup # noqa: F401,E501
-from fatcat_client.models.work_entity import WorkEntity # noqa: F401,E501
+from fatcat_openapi_client.models.editgroup import Editgroup # noqa: F401,E501
+from fatcat_openapi_client.models.work_entity import WorkEntity # noqa: F401,E501
class WorkAutoBatch(object):
diff --git a/python_client/fatcat_client/models/work_entity.py b/python_openapi_client/fatcat_openapi_client/models/work_entity.py
index 80cb2330..80cb2330 100644
--- a/python_client/fatcat_client/models/work_entity.py
+++ b/python_openapi_client/fatcat_openapi_client/models/work_entity.py
diff --git a/python_client/fatcat_client/rest.py b/python_openapi_client/fatcat_openapi_client/rest.py
index 59ce1b74..59ce1b74 100644
--- a/python_client/fatcat_client/rest.py
+++ b/python_openapi_client/fatcat_openapi_client/rest.py
diff --git a/python_client/pytest.ini b/python_openapi_client/pytest.ini
index 98060611..98e77c63 100644
--- a/python_client/pytest.ini
+++ b/python_openapi_client/pytest.ini
@@ -4,7 +4,7 @@
ignore = setup.py
# allow imports from files in current directory
-python_paths = fatcat_client, tests
+python_paths = fatcat_openapi_client, tests
# search for 'test_*' functions in all python files, not just under tests
python_files = *.py
diff --git a/python_client/tests/codegen/__init__.py b/python_openapi_client/tests/codegen/__init__.py
index e69de29b..e69de29b 100644
--- a/python_client/tests/codegen/__init__.py
+++ b/python_openapi_client/tests/codegen/__init__.py
diff --git a/python_client/tests/codegen/test_auth_oidc.py b/python_openapi_client/tests/codegen/test_auth_oidc.py
index 7495a16a..489cac61 100644
--- a/python_client/tests/codegen/test_auth_oidc.py
+++ b/python_openapi_client/tests/codegen/test_auth_oidc.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.auth_oidc import AuthOidc # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.auth_oidc import AuthOidc # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestAuthOidc(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestAuthOidc(unittest.TestCase):
def testAuthOidc(self):
"""Test AuthOidc"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.auth_oidc.AuthOidc() # noqa: E501
+ # model = fatcat_openapi_client.models.auth_oidc.AuthOidc() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_auth_oidc_result.py b/python_openapi_client/tests/codegen/test_auth_oidc_result.py
index bf158fbd..5962d954 100644
--- a/python_client/tests/codegen/test_auth_oidc_result.py
+++ b/python_openapi_client/tests/codegen/test_auth_oidc_result.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.auth_oidc_result import AuthOidcResult # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.auth_oidc_result import AuthOidcResult # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestAuthOidcResult(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestAuthOidcResult(unittest.TestCase):
def testAuthOidcResult(self):
"""Test AuthOidcResult"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.auth_oidc_result.AuthOidcResult() # noqa: E501
+ # model = fatcat_openapi_client.models.auth_oidc_result.AuthOidcResult() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_changelog_entry.py b/python_openapi_client/tests/codegen/test_changelog_entry.py
index 0167a317..813307a6 100644
--- a/python_client/tests/codegen/test_changelog_entry.py
+++ b/python_openapi_client/tests/codegen/test_changelog_entry.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.changelog_entry import ChangelogEntry # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.changelog_entry import ChangelogEntry # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestChangelogEntry(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestChangelogEntry(unittest.TestCase):
def testChangelogEntry(self):
"""Test ChangelogEntry"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.changelog_entry.ChangelogEntry() # noqa: E501
+ # model = fatcat_openapi_client.models.changelog_entry.ChangelogEntry() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_container_auto_batch.py b/python_openapi_client/tests/codegen/test_container_auto_batch.py
index 136bc48f..8eba8a6d 100644
--- a/python_client/tests/codegen/test_container_auto_batch.py
+++ b/python_openapi_client/tests/codegen/test_container_auto_batch.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.container_auto_batch import ContainerAutoBatch # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.container_auto_batch import ContainerAutoBatch # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestContainerAutoBatch(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestContainerAutoBatch(unittest.TestCase):
def testContainerAutoBatch(self):
"""Test ContainerAutoBatch"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.container_auto_batch.ContainerAutoBatch() # noqa: E501
+ # model = fatcat_openapi_client.models.container_auto_batch.ContainerAutoBatch() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_container_entity.py b/python_openapi_client/tests/codegen/test_container_entity.py
index 79ed9fa6..32771475 100644
--- a/python_client/tests/codegen/test_container_entity.py
+++ b/python_openapi_client/tests/codegen/test_container_entity.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.container_entity import ContainerEntity # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.container_entity import ContainerEntity # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestContainerEntity(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestContainerEntity(unittest.TestCase):
def testContainerEntity(self):
"""Test ContainerEntity"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.container_entity.ContainerEntity() # noqa: E501
+ # model = fatcat_openapi_client.models.container_entity.ContainerEntity() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_creator_auto_batch.py b/python_openapi_client/tests/codegen/test_creator_auto_batch.py
index 0bee20d1..9181c098 100644
--- a/python_client/tests/codegen/test_creator_auto_batch.py
+++ b/python_openapi_client/tests/codegen/test_creator_auto_batch.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.creator_auto_batch import CreatorAutoBatch # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.creator_auto_batch import CreatorAutoBatch # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestCreatorAutoBatch(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestCreatorAutoBatch(unittest.TestCase):
def testCreatorAutoBatch(self):
"""Test CreatorAutoBatch"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.creator_auto_batch.CreatorAutoBatch() # noqa: E501
+ # model = fatcat_openapi_client.models.creator_auto_batch.CreatorAutoBatch() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_creator_entity.py b/python_openapi_client/tests/codegen/test_creator_entity.py
index f51ba124..2b55ff26 100644
--- a/python_client/tests/codegen/test_creator_entity.py
+++ b/python_openapi_client/tests/codegen/test_creator_entity.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.creator_entity import CreatorEntity # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.creator_entity import CreatorEntity # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestCreatorEntity(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestCreatorEntity(unittest.TestCase):
def testCreatorEntity(self):
"""Test CreatorEntity"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.creator_entity.CreatorEntity() # noqa: E501
+ # model = fatcat_openapi_client.models.creator_entity.CreatorEntity() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_default_api.py b/python_openapi_client/tests/codegen/test_default_api.py
index 1fd2c4cd..3ea87237 100644
--- a/python_client/tests/codegen/test_default_api.py
+++ b/python_openapi_client/tests/codegen/test_default_api.py
@@ -15,16 +15,16 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.api.default_api import DefaultApi # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.api.default_api import DefaultApi # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestDefaultApi(unittest.TestCase):
"""DefaultApi unit test stubs"""
def setUp(self):
- self.api = fatcat_client.api.default_api.DefaultApi() # noqa: E501
+ self.api = fatcat_openapi_client.api.default_api.DefaultApi() # noqa: E501
def tearDown(self):
pass
diff --git a/python_client/tests/codegen/test_editgroup.py b/python_openapi_client/tests/codegen/test_editgroup.py
index a9f84cfe..41282829 100644
--- a/python_client/tests/codegen/test_editgroup.py
+++ b/python_openapi_client/tests/codegen/test_editgroup.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.editgroup import Editgroup # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.editgroup import Editgroup # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestEditgroup(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestEditgroup(unittest.TestCase):
def testEditgroup(self):
"""Test Editgroup"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.editgroup.Editgroup() # noqa: E501
+ # model = fatcat_openapi_client.models.editgroup.Editgroup() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_editgroup_annotation.py b/python_openapi_client/tests/codegen/test_editgroup_annotation.py
index a5ada569..4e4f3e25 100644
--- a/python_client/tests/codegen/test_editgroup_annotation.py
+++ b/python_openapi_client/tests/codegen/test_editgroup_annotation.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.editgroup_annotation import EditgroupAnnotation # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.editgroup_annotation import EditgroupAnnotation # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestEditgroupAnnotation(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestEditgroupAnnotation(unittest.TestCase):
def testEditgroupAnnotation(self):
"""Test EditgroupAnnotation"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.editgroup_annotation.EditgroupAnnotation() # noqa: E501
+ # model = fatcat_openapi_client.models.editgroup_annotation.EditgroupAnnotation() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_editgroup_edits.py b/python_openapi_client/tests/codegen/test_editgroup_edits.py
index 696b9baa..5d3cebe8 100644
--- a/python_client/tests/codegen/test_editgroup_edits.py
+++ b/python_openapi_client/tests/codegen/test_editgroup_edits.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.editgroup_edits import EditgroupEdits # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.editgroup_edits import EditgroupEdits # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestEditgroupEdits(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestEditgroupEdits(unittest.TestCase):
def testEditgroupEdits(self):
"""Test EditgroupEdits"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.editgroup_edits.EditgroupEdits() # noqa: E501
+ # model = fatcat_openapi_client.models.editgroup_edits.EditgroupEdits() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_editor.py b/python_openapi_client/tests/codegen/test_editor.py
index 3add4f28..65064564 100644
--- a/python_client/tests/codegen/test_editor.py
+++ b/python_openapi_client/tests/codegen/test_editor.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.editor import Editor # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.editor import Editor # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestEditor(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestEditor(unittest.TestCase):
def testEditor(self):
"""Test Editor"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.editor.Editor() # noqa: E501
+ # model = fatcat_openapi_client.models.editor.Editor() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_entity_edit.py b/python_openapi_client/tests/codegen/test_entity_edit.py
index fe8410c6..cc097c3d 100644
--- a/python_client/tests/codegen/test_entity_edit.py
+++ b/python_openapi_client/tests/codegen/test_entity_edit.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.entity_edit import EntityEdit # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.entity_edit import EntityEdit # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestEntityEdit(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestEntityEdit(unittest.TestCase):
def testEntityEdit(self):
"""Test EntityEdit"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.entity_edit.EntityEdit() # noqa: E501
+ # model = fatcat_openapi_client.models.entity_edit.EntityEdit() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_entity_history_entry.py b/python_openapi_client/tests/codegen/test_entity_history_entry.py
index cd35097a..7a6e7146 100644
--- a/python_client/tests/codegen/test_entity_history_entry.py
+++ b/python_openapi_client/tests/codegen/test_entity_history_entry.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.entity_history_entry import EntityHistoryEntry # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.entity_history_entry import EntityHistoryEntry # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestEntityHistoryEntry(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestEntityHistoryEntry(unittest.TestCase):
def testEntityHistoryEntry(self):
"""Test EntityHistoryEntry"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.entity_history_entry.EntityHistoryEntry() # noqa: E501
+ # model = fatcat_openapi_client.models.entity_history_entry.EntityHistoryEntry() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_error_response.py b/python_openapi_client/tests/codegen/test_error_response.py
index 4463ca9f..04f8baa2 100644
--- a/python_client/tests/codegen/test_error_response.py
+++ b/python_openapi_client/tests/codegen/test_error_response.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.error_response import ErrorResponse # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.error_response import ErrorResponse # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestErrorResponse(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestErrorResponse(unittest.TestCase):
def testErrorResponse(self):
"""Test ErrorResponse"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.error_response.ErrorResponse() # noqa: E501
+ # model = fatcat_openapi_client.models.error_response.ErrorResponse() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_file_auto_batch.py b/python_openapi_client/tests/codegen/test_file_auto_batch.py
index 56e272d6..407f60fc 100644
--- a/python_client/tests/codegen/test_file_auto_batch.py
+++ b/python_openapi_client/tests/codegen/test_file_auto_batch.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.file_auto_batch import FileAutoBatch # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.file_auto_batch import FileAutoBatch # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestFileAutoBatch(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestFileAutoBatch(unittest.TestCase):
def testFileAutoBatch(self):
"""Test FileAutoBatch"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.file_auto_batch.FileAutoBatch() # noqa: E501
+ # model = fatcat_openapi_client.models.file_auto_batch.FileAutoBatch() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_file_entity.py b/python_openapi_client/tests/codegen/test_file_entity.py
index 140daeed..790a3280 100644
--- a/python_client/tests/codegen/test_file_entity.py
+++ b/python_openapi_client/tests/codegen/test_file_entity.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.file_entity import FileEntity # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.file_entity import FileEntity # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestFileEntity(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestFileEntity(unittest.TestCase):
def testFileEntity(self):
"""Test FileEntity"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.file_entity.FileEntity() # noqa: E501
+ # model = fatcat_openapi_client.models.file_entity.FileEntity() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_file_url.py b/python_openapi_client/tests/codegen/test_file_url.py
index 9ac6281f..8b15fffa 100644
--- a/python_client/tests/codegen/test_file_url.py
+++ b/python_openapi_client/tests/codegen/test_file_url.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.file_url import FileUrl # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.file_url import FileUrl # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestFileUrl(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestFileUrl(unittest.TestCase):
def testFileUrl(self):
"""Test FileUrl"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.file_url.FileUrl() # noqa: E501
+ # model = fatcat_openapi_client.models.file_url.FileUrl() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_fileset_auto_batch.py b/python_openapi_client/tests/codegen/test_fileset_auto_batch.py
index d213b43d..4b28e4c1 100644
--- a/python_client/tests/codegen/test_fileset_auto_batch.py
+++ b/python_openapi_client/tests/codegen/test_fileset_auto_batch.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.fileset_auto_batch import FilesetAutoBatch # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.fileset_auto_batch import FilesetAutoBatch # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestFilesetAutoBatch(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestFilesetAutoBatch(unittest.TestCase):
def testFilesetAutoBatch(self):
"""Test FilesetAutoBatch"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.fileset_auto_batch.FilesetAutoBatch() # noqa: E501
+ # model = fatcat_openapi_client.models.fileset_auto_batch.FilesetAutoBatch() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_fileset_entity.py b/python_openapi_client/tests/codegen/test_fileset_entity.py
index 5e22b821..629c901f 100644
--- a/python_client/tests/codegen/test_fileset_entity.py
+++ b/python_openapi_client/tests/codegen/test_fileset_entity.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.fileset_entity import FilesetEntity # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.fileset_entity import FilesetEntity # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestFilesetEntity(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestFilesetEntity(unittest.TestCase):
def testFilesetEntity(self):
"""Test FilesetEntity"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.fileset_entity.FilesetEntity() # noqa: E501
+ # model = fatcat_openapi_client.models.fileset_entity.FilesetEntity() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_fileset_file.py b/python_openapi_client/tests/codegen/test_fileset_file.py
index 817b3916..99cc6172 100644
--- a/python_client/tests/codegen/test_fileset_file.py
+++ b/python_openapi_client/tests/codegen/test_fileset_file.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.fileset_file import FilesetFile # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.fileset_file import FilesetFile # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestFilesetFile(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestFilesetFile(unittest.TestCase):
def testFilesetFile(self):
"""Test FilesetFile"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.fileset_file.FilesetFile() # noqa: E501
+ # model = fatcat_openapi_client.models.fileset_file.FilesetFile() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_fileset_url.py b/python_openapi_client/tests/codegen/test_fileset_url.py
index ae34d0e0..657c3568 100644
--- a/python_client/tests/codegen/test_fileset_url.py
+++ b/python_openapi_client/tests/codegen/test_fileset_url.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.fileset_url import FilesetUrl # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.fileset_url import FilesetUrl # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestFilesetUrl(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestFilesetUrl(unittest.TestCase):
def testFilesetUrl(self):
"""Test FilesetUrl"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.fileset_url.FilesetUrl() # noqa: E501
+ # model = fatcat_openapi_client.models.fileset_url.FilesetUrl() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_release_abstract.py b/python_openapi_client/tests/codegen/test_release_abstract.py
index ee962b48..50b250bb 100644
--- a/python_client/tests/codegen/test_release_abstract.py
+++ b/python_openapi_client/tests/codegen/test_release_abstract.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.release_abstract import ReleaseAbstract # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.release_abstract import ReleaseAbstract # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestReleaseAbstract(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestReleaseAbstract(unittest.TestCase):
def testReleaseAbstract(self):
"""Test ReleaseAbstract"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.release_abstract.ReleaseAbstract() # noqa: E501
+ # model = fatcat_openapi_client.models.release_abstract.ReleaseAbstract() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_release_auto_batch.py b/python_openapi_client/tests/codegen/test_release_auto_batch.py
index 23ecbcc1..9d9ab7e4 100644
--- a/python_client/tests/codegen/test_release_auto_batch.py
+++ b/python_openapi_client/tests/codegen/test_release_auto_batch.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.release_auto_batch import ReleaseAutoBatch # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.release_auto_batch import ReleaseAutoBatch # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestReleaseAutoBatch(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestReleaseAutoBatch(unittest.TestCase):
def testReleaseAutoBatch(self):
"""Test ReleaseAutoBatch"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.release_auto_batch.ReleaseAutoBatch() # noqa: E501
+ # model = fatcat_openapi_client.models.release_auto_batch.ReleaseAutoBatch() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_release_contrib.py b/python_openapi_client/tests/codegen/test_release_contrib.py
index 33e1e621..4c9daf7d 100644
--- a/python_client/tests/codegen/test_release_contrib.py
+++ b/python_openapi_client/tests/codegen/test_release_contrib.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.release_contrib import ReleaseContrib # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.release_contrib import ReleaseContrib # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestReleaseContrib(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestReleaseContrib(unittest.TestCase):
def testReleaseContrib(self):
"""Test ReleaseContrib"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.release_contrib.ReleaseContrib() # noqa: E501
+ # model = fatcat_openapi_client.models.release_contrib.ReleaseContrib() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_release_entity.py b/python_openapi_client/tests/codegen/test_release_entity.py
index c9284fe8..bee996c1 100644
--- a/python_client/tests/codegen/test_release_entity.py
+++ b/python_openapi_client/tests/codegen/test_release_entity.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.release_entity import ReleaseEntity # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.release_entity import ReleaseEntity # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestReleaseEntity(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestReleaseEntity(unittest.TestCase):
def testReleaseEntity(self):
"""Test ReleaseEntity"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.release_entity.ReleaseEntity() # noqa: E501
+ # model = fatcat_openapi_client.models.release_entity.ReleaseEntity() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_release_ext_ids.py b/python_openapi_client/tests/codegen/test_release_ext_ids.py
index 6532cbd2..9dce44ee 100644
--- a/python_client/tests/codegen/test_release_ext_ids.py
+++ b/python_openapi_client/tests/codegen/test_release_ext_ids.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.release_ext_ids import ReleaseExtIds # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.release_ext_ids import ReleaseExtIds # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestReleaseExtIds(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestReleaseExtIds(unittest.TestCase):
def testReleaseExtIds(self):
"""Test ReleaseExtIds"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.release_ext_ids.ReleaseExtIds() # noqa: E501
+ # model = fatcat_openapi_client.models.release_ext_ids.ReleaseExtIds() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_release_ref.py b/python_openapi_client/tests/codegen/test_release_ref.py
index 020c6436..33574195 100644
--- a/python_client/tests/codegen/test_release_ref.py
+++ b/python_openapi_client/tests/codegen/test_release_ref.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.release_ref import ReleaseRef # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.release_ref import ReleaseRef # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestReleaseRef(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestReleaseRef(unittest.TestCase):
def testReleaseRef(self):
"""Test ReleaseRef"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.release_ref.ReleaseRef() # noqa: E501
+ # model = fatcat_openapi_client.models.release_ref.ReleaseRef() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_success.py b/python_openapi_client/tests/codegen/test_success.py
index df26d217..f661977a 100644
--- a/python_client/tests/codegen/test_success.py
+++ b/python_openapi_client/tests/codegen/test_success.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.success import Success # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.success import Success # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestSuccess(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestSuccess(unittest.TestCase):
def testSuccess(self):
"""Test Success"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.success.Success() # noqa: E501
+ # model = fatcat_openapi_client.models.success.Success() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_webcapture_auto_batch.py b/python_openapi_client/tests/codegen/test_webcapture_auto_batch.py
index 8c2b8000..766294ea 100644
--- a/python_client/tests/codegen/test_webcapture_auto_batch.py
+++ b/python_openapi_client/tests/codegen/test_webcapture_auto_batch.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.webcapture_auto_batch import WebcaptureAutoBatch # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.webcapture_auto_batch import WebcaptureAutoBatch # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestWebcaptureAutoBatch(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestWebcaptureAutoBatch(unittest.TestCase):
def testWebcaptureAutoBatch(self):
"""Test WebcaptureAutoBatch"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.webcapture_auto_batch.WebcaptureAutoBatch() # noqa: E501
+ # model = fatcat_openapi_client.models.webcapture_auto_batch.WebcaptureAutoBatch() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_webcapture_cdx_line.py b/python_openapi_client/tests/codegen/test_webcapture_cdx_line.py
index d044ded2..4706395d 100644
--- a/python_client/tests/codegen/test_webcapture_cdx_line.py
+++ b/python_openapi_client/tests/codegen/test_webcapture_cdx_line.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.webcapture_cdx_line import WebcaptureCdxLine # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.webcapture_cdx_line import WebcaptureCdxLine # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestWebcaptureCdxLine(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestWebcaptureCdxLine(unittest.TestCase):
def testWebcaptureCdxLine(self):
"""Test WebcaptureCdxLine"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.webcapture_cdx_line.WebcaptureCdxLine() # noqa: E501
+ # model = fatcat_openapi_client.models.webcapture_cdx_line.WebcaptureCdxLine() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_webcapture_entity.py b/python_openapi_client/tests/codegen/test_webcapture_entity.py
index 2bfb034f..d96c96e4 100644
--- a/python_client/tests/codegen/test_webcapture_entity.py
+++ b/python_openapi_client/tests/codegen/test_webcapture_entity.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.webcapture_entity import WebcaptureEntity # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.webcapture_entity import WebcaptureEntity # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestWebcaptureEntity(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestWebcaptureEntity(unittest.TestCase):
def testWebcaptureEntity(self):
"""Test WebcaptureEntity"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.webcapture_entity.WebcaptureEntity() # noqa: E501
+ # model = fatcat_openapi_client.models.webcapture_entity.WebcaptureEntity() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_webcapture_url.py b/python_openapi_client/tests/codegen/test_webcapture_url.py
index 951ef208..fc15736e 100644
--- a/python_client/tests/codegen/test_webcapture_url.py
+++ b/python_openapi_client/tests/codegen/test_webcapture_url.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.webcapture_url import WebcaptureUrl # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.webcapture_url import WebcaptureUrl # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestWebcaptureUrl(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestWebcaptureUrl(unittest.TestCase):
def testWebcaptureUrl(self):
"""Test WebcaptureUrl"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.webcapture_url.WebcaptureUrl() # noqa: E501
+ # model = fatcat_openapi_client.models.webcapture_url.WebcaptureUrl() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_work_auto_batch.py b/python_openapi_client/tests/codegen/test_work_auto_batch.py
index 92edcaf5..16cbe693 100644
--- a/python_client/tests/codegen/test_work_auto_batch.py
+++ b/python_openapi_client/tests/codegen/test_work_auto_batch.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.work_auto_batch import WorkAutoBatch # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.work_auto_batch import WorkAutoBatch # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestWorkAutoBatch(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestWorkAutoBatch(unittest.TestCase):
def testWorkAutoBatch(self):
"""Test WorkAutoBatch"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.work_auto_batch.WorkAutoBatch() # noqa: E501
+ # model = fatcat_openapi_client.models.work_auto_batch.WorkAutoBatch() # noqa: E501
pass
diff --git a/python_client/tests/codegen/test_work_entity.py b/python_openapi_client/tests/codegen/test_work_entity.py
index 6c49f3a2..5a0936a9 100644
--- a/python_client/tests/codegen/test_work_entity.py
+++ b/python_openapi_client/tests/codegen/test_work_entity.py
@@ -15,9 +15,9 @@ from __future__ import absolute_import
import unittest
-import fatcat_client
-from fatcat_client.models.work_entity import WorkEntity # noqa: E501
-from fatcat_client.rest import ApiException
+import fatcat_openapi_client
+from fatcat_openapi_client.models.work_entity import WorkEntity # noqa: E501
+from fatcat_openapi_client.rest import ApiException
class TestWorkEntity(unittest.TestCase):
@@ -32,7 +32,7 @@ class TestWorkEntity(unittest.TestCase):
def testWorkEntity(self):
"""Test WorkEntity"""
# FIXME: construct object with mandatory attributes with example values
- # model = fatcat_client.models.work_entity.WorkEntity() # noqa: E501
+ # model = fatcat_openapi_client.models.work_entity.WorkEntity() # noqa: E501
pass
diff --git a/python_client/codegen_python_client.sh b/python_openapi_client/codegen_python_client.sh
index 4ffb4de0..c602bc19 100755
--- a/python_client/codegen_python_client.sh
+++ b/python_openapi_client/codegen_python_client.sh
@@ -1,6 +1,6 @@
#!/bin/bash
# This script re-generates the fatcat API client (fatcat_client) from the
# swagger/openapi2 spec file, using automated tools ("codegen")
set -exu
@@ -18,17 +18,17 @@ docker run \
--lang python \
--input-spec /tmp/swagger/api.yml \
--output /tmp/swagger/ \
- -DpackageName=fatcat_client
+ -DpackageName=fatcat_openapi_client
sudo chown -R `whoami`:`whoami` $OUTPUT
-mkdir -p fatcat_client
-cp -r $OUTPUT/fatcat_client/* fatcat_client
+mkdir -p fatcat_openapi_client
+cp -r $OUTPUT/fatcat_openapi_client/* fatcat_openapi_client
cp $OUTPUT/README.md README.md
# fix an annoying/buggy __del__() in codegen
patch -p0 << END_PATCH
---- fatcat_client/api_client.py
-+++ fatcat_client/api_client.py
+--- fatcat_openapi_client/api_client.py
++++ fatcat_openapi_client/api_client.py
@@ -76,8 +76,11 @@ class ApiClient(object):
self.user_agent = 'Swagger-Codegen/1.0.0/python'
@@ -50,8 +50,8 @@ END_PATCH
# clients in parallel.
# See also: https://github.com/swagger-api/swagger-codegen/issues/9117
patch -p0 << END_PATCH
---- fatcat_client/configuration.py
-+++ fatcat_client/configuration.py
+--- fatcat_openapi_client/configuration.py
++++ fatcat_openapi_client/configuration.py
@@ -37,7 +37,7 @@ class TypeWithDefault(type):
cls._default = copy.copy(default)
@@ -65,35 +65,35 @@ END_PATCH
# fix circular import (release/file/fileset/webcapture)
patch -p0 << END_PATCH
---- fatcat_client/models/file_entity.py
-+++ fatcat_client/models/file_entity.py
+--- fatcat_openapi_client/models/file_entity.py
++++ fatcat_openapi_client/models/file_entity.py
@@ -17,7 +17,6 @@ import re # noqa: F401
import six
- from fatcat_client.models.file_url import FileUrl # noqa: F401,E501
--from fatcat_client.models.release_entity import ReleaseEntity # noqa: F401,E501
+ from fatcat_openapi_client.models.file_url import FileUrl # noqa: F401,E501
+-from fatcat_openapi_client.models.release_entity import ReleaseEntity # noqa: F401,E501
class FileEntity(object):
---- fatcat_client/models/fileset_entity.py
-+++ fatcat_client/models/fileset_entity.py
+--- fatcat_openapi_client/models/fileset_entity.py
++++ fatcat_openapi_client/models/fileset_entity.py
@@ -18,7 +18,6 @@ import six
- from fatcat_client.models.fileset_file import FilesetFile # noqa: F401,E501
- from fatcat_client.models.fileset_url import FilesetUrl # noqa: F401,E501
--from fatcat_client.models.release_entity import ReleaseEntity # noqa: F401,E501
+ from fatcat_openapi_client.models.fileset_file import FilesetFile # noqa: F401,E501
+ from fatcat_openapi_client.models.fileset_url import FilesetUrl # noqa: F401,E501
+-from fatcat_openapi_client.models.release_entity import ReleaseEntity # noqa: F401,E501
class FilesetEntity(object):
---- fatcat_client/models/webcapture_entity.py
-+++ fatcat_client/models/webcapture_entity.py
+--- fatcat_openapi_client/models/webcapture_entity.py
++++ fatcat_openapi_client/models/webcapture_entity.py
@@ -16,7 +16,6 @@ import re # noqa: F401
import six
--from fatcat_client.models.release_entity import ReleaseEntity # noqa: F401,E501
- from fatcat_client.models.webcapture_cdx_line import WebcaptureCdxLine # noqa: F401,E501
- from fatcat_client.models.webcapture_url import WebcaptureUrl # noqa: F401,E501
+-from fatcat_openapi_client.models.release_entity import ReleaseEntity # noqa: F401,E501
+ from fatcat_openapi_client.models.webcapture_cdx_line import WebcaptureCdxLine # noqa: F401,E501
+ from fatcat_openapi_client.models.webcapture_url import WebcaptureUrl # noqa: F401,E501
END_PATCH
# these tests are basically no-ops
@@ -1,6 +1,6 @@
#!/bin/bash
-# This script re-generates the fatcat API client (fatcat_client) from the
+# This script re-generates the fatcat API client (fatcat-openapi-client) from the
# swagger/openapi2 spec file, using automated tools ("codegen")
set -exu
diff --git a/python_client/setup.py b/python_openapi_client/setup.py
index 107f3f5b..a7809ab2 100644
--- a/python_client/setup.py
+++ b/python_openapi_client/setup.py
@@ -2,7 +2,7 @@
# -*- coding: utf-8 -*-
# Based on: https://github.com/kennethreitz/setup.py
# This setup.py is intended to package *only* the fatcat_client module.
# Note: To use the 'upload' functionality of this file, you must:
# $ pip install twine
@@ -15,7 +15,7 @@ from shutil import rmtree
from setuptools import find_packages, setup, Command
# Package meta-data.
-NAME = 'fatcat_client'
+NAME = 'fatcat_openapi_client'
DESCRIPTION = 'API client library for fatcat.wiki (a bibliographic catalog)'
URL = 'https://github.com/internetarchive/fatcat'
EMAIL = 'bnewbold@archive.org'
@@ -112,7 +112,7 @@ setup(
url=URL,
packages=find_packages(exclude=('tests')),
# If your package is a single module, use this instead of 'packages':
- #py_modules=['fatcat_client'],
+ #py_modules=['fatcat_openapi_client'],
# entry_points={
# 'console_scripts': ['mycli=mymodule:cli'],
# },
@@ -2,7 +2,7 @@
# -*- coding: utf-8 -*-
# Based on: https://github.com/kennethreitz/setup.py
-# This setup.py is intended to package *only* the fatcat_client module.
+# This setup.py is intended to package *only* the fatcat_openapi_client module.
# Note: To use the 'upload' functionality of this file, you must:
# $ pip install twine